Build the file path for a single plot output
build_plot_path.RdBuild the file path for a single plot output
Arguments
- file_id
Character; file identifier used as the base of the filename.
- ch_id
Character; channel identifier (e.g.
"ch1").- ch_id_folder
Character; directory where the plot file will be saved.
- plot_name
Character; plot-type name appended to the filename.
- save_format
Character; file extension (e.g.
"svg").